-- Create database if it doesn't exist (optional)
-- CREATE DATABASE InnovateDB_National;
-- GO
-- USE InnovateDB_National;
-- GO

-- Drop tables if they exist (reverse order of dependency)
IF OBJECT_ID('dbo.InventoryTransactions', 'U') IS NOT NULL
  DROP TABLE dbo.InventoryTransactions;
GO
IF OBJECT_ID('dbo.Products', 'U') IS NOT NULL
  DROP TABLE dbo.Products;
GO
IF OBJECT_ID('dbo.Suppliers', 'U') IS NOT NULL
  DROP TABLE dbo.Suppliers;
GO

-- Create Suppliers table
CREATE TABLE Suppliers (
    SupplierID INT IDENTITY(1,1) PRIMARY KEY,
    -- SupplierID INTEGER PRIMARY KEY AUTOINCREMENT, -- SQLite
    Name VARCHAR(150) NOT NULL,
    ContactPerson VARCHAR(100) NULL
);
GO

-- Create Products table
CREATE TABLE Products (
    ProductID INT IDENTITY(1001,1) PRIMARY KEY, -- Start ProductID at 1001
    -- ProductID INTEGER PRIMARY KEY AUTOINCREMENT, -- SQLite
    Name VARCHAR(100) NOT NULL,
    SupplierID INT NULL,
    CurrentStock INT NOT NULL DEFAULT 0,
    ReorderLevel INT NULL DEFAULT 10, -- Add ReorderLevel
    CONSTRAINT FK_Products_Suppliers FOREIGN KEY (SupplierID) REFERENCES Suppliers(SupplierID) ON DELETE SET NULL -- If supplier deleted, set Product's supplier to NULL
);
GO

-- Create InventoryTransactions table
CREATE TABLE InventoryTransactions (
    TransactionID INT IDENTITY(1,1) PRIMARY KEY,
    -- TransactionID INTEGER PRIMARY KEY AUTOINCREMENT, -- SQLite
    ProductID INT NOT NULL,
    ChangeQuantity INT NOT NULL, -- Positive for received, Negative for shipped
    TransactionDate DATETIME NOT NULL DEFAULT GETDATE(), -- SQL Server
    -- TransactionDate TEXT NOT NULL DEFAULT CURRENT_TIMESTAMP, -- SQLite
    Notes VARCHAR(255) NULL,
    CONSTRAINT FK_InventoryTransactions_Products FOREIGN KEY (ProductID) REFERENCES Products(ProductID) ON DELETE CASCADE -- If product deleted, delete transactions
);
GO

-- Insert sample data
INSERT INTO Suppliers (Name, ContactPerson) VALUES
('Global Supplies Co.', 'Jane Doe'),
('Tech Components Ltd.', 'John Smith');
GO

DECLARE @SupplierA INT = (SELECT SupplierID FROM Suppliers WHERE Name = 'Global Supplies Co.');
DECLARE @SupplierB INT = (SELECT SupplierID FROM Suppliers WHERE Name = 'Tech Components Ltd.');

INSERT INTO Products (Name, SupplierID, CurrentStock, ReorderLevel) VALUES
('Power Unit X', @SupplierA, 50, 20),
('Sensor Module Y', @SupplierB, 100, 50),
('Assembly Kit Z', @SupplierA, 30, 15);
GO

DECLARE @ProductX INT = (SELECT ProductID FROM Products WHERE Name = 'Power Unit X');
DECLARE @ProductY INT = (SELECT ProductID FROM Products WHERE Name = 'Sensor Module Y');

INSERT INTO InventoryTransactions (ProductID, ChangeQuantity, TransactionDate, Notes) VALUES
(@ProductX, 50, DATEADD(day, -2, GETDATE()), 'Initial stock receipt'),
(@ProductY, 100, DATEADD(day, -2, GETDATE()), 'Initial stock receipt'),
(@ProductX, -10, DATEADD(day, -1, GETDATE()), 'Shipped Order #101'),
(@ProductY, 25, GETDATE(), 'Received Shipment #201');
GO

-- Adjust CurrentStock based on recent transaction (example - usually done by app)
UPDATE Products SET CurrentStock = CurrentStock + 25 WHERE ProductID = @ProductY;
GO


-- Verify insertion
SELECT * FROM Suppliers;
SELECT * FROM Products;
SELECT * FROM InventoryTransactions;
GO