-- Create database if it doesn't exist (optional)
-- CREATE DATABASE InnovateDB_State;
-- GO
-- USE InnovateDB_State;
-- GO

-- Drop tables if they exist (in reverse order of dependency)
IF OBJECT_ID('dbo.Orders', 'U') IS NOT NULL
  DROP TABLE dbo.Orders;
GO
IF OBJECT_ID('dbo.Customers', 'U') IS NOT NULL
  DROP TABLE dbo.Customers;
GO

-- Create Customers table
CREATE TABLE Customers (
    CustomerID INT IDENTITY(101,1) PRIMARY KEY, -- Start CustomerID at 101
    -- CustomerID INTEGER PRIMARY KEY AUTOINCREMENT, -- Use for SQLite (doesn't support seed)
    Name VARCHAR(100) NOT NULL,
    Email VARCHAR(100) UNIQUE -- Ensure emails are unique
);
GO

-- Create Orders table
CREATE TABLE Orders (
    OrderID INT IDENTITY(1,1) PRIMARY KEY,
    -- OrderID INTEGER PRIMARY KEY AUTOINCREMENT, -- Use for SQLite
    CustomerID INT NOT NULL,
    OrderDate DATETIME NULL DEFAULT GETDATE(), -- Default to current time for SQL Server
    -- OrderDate TEXT NULL DEFAULT CURRENT_TIMESTAMP, -- Use for SQLite
    Amount DECIMAL(12, 2) NULL,
    CONSTRAINT FK_Orders_Customers FOREIGN KEY (CustomerID) REFERENCES Customers(CustomerID) ON DELETE CASCADE -- If customer deleted, delete their orders
);
GO

-- Insert sample data
INSERT INTO Customers (Name, Email) VALUES
('Alice Smith', 'alice.s@example.com'),
('Bob Johnson', 'bob.j@example.com'),
('Charlie Brown', 'charlie.b@example.com');
GO

-- Get Customer IDs for orders (adjust if identity seed is different)
DECLARE @AliceID INT = (SELECT CustomerID FROM Customers WHERE Email = 'alice.s@example.com');
DECLARE @BobID INT = (SELECT CustomerID FROM Customers WHERE Email = 'bob.j@example.com');

INSERT INTO Orders (CustomerID, OrderDate, Amount) VALUES
(@AliceID, '2025-04-15 10:30:00', 125.50),
(@BobID, '2025-04-16 11:00:00', 75.00),
(@AliceID, '2025-04-17 14:00:00', 80.25);
GO

-- Verify insertion
SELECT * FROM Customers;
SELECT * FROM Orders;
GO